@@ -4,7 +4,7 @@ use v5.14;
 use warnings;
 use utf8;
 
-our $VERSION = "2.2702";
+our $VERSION = "2.28";
 
 use Data::Dumper;
 {
@@ -53,11 +53,14 @@ our $nonspace_re = qr{ \p{IsPrintableLatin} }x;
 our $reset_re    = qr{ \e \[ [0;]* m }x;
 our $color_re    = qr{ \e \[ [\d;]* m }x;
 our $erase_re    = qr{ \e \[ [\d;]* K }x;
-our $csi_re      = qr{
+our $csi_body_re = qr{
     # see ECMA-48 5.4 Control sequences
     (?: \e\[ | \x9b )	# csi
     [\x30-\x3f]*	# parameter bytes
     [\x20-\x2f]*	# intermediate bytes
+}x;
+our $csi_re      = qr{
+    $csi_body_re
     [\x40-\x7e]		# final byte
 }x;
 our $osc_re      = qr{
@@ -369,6 +372,12 @@ sub fold {
 	    next;
 	}
 
+	# imcomplete CSI
+	if (s/\A(\e|$csi_body_re)\z//) {
+	    $folded .= $1;
+	    last;
+	}
+
 	# tab
 	if ($opt->{expand} and s/\A\t//) {
 	    my $space = $opt->{tabstop} - ($width - $room) % $opt->{tabstop};
@@ -600,7 +609,7 @@ Text::ANSI::Fold - Text folding library supporting ANSI terminal sequence and As
 
 =head1 VERSION
 
-Version 2.2702
+Version 2.28
 
 =head1 SYNOPSIS
 
@@ -754,7 +763,7 @@ use C<text> and C<chops> in series:
 
     print join "\n", $obj->text($string)->chops;
 
-Actually, text can be set by c<new> or C<configure> method through
+Actually, text can be set by C<new> or C<configure> method through
 C<text> parameter.  Next program just works.
 
     use Text::ANSI::Fold;
